@@ -515,6 +515,10 @@ class XmlStartElement:
             '<IIHHHHHH', attrext_data)
         attrext = [full_namespace_index, name_index, attr_start, attr_size, attr_count, id_index, class_index,
                    style_index]
+        if attr_start != 20:
+            # Cover for dummy data between ResXMLTree_attrExt and the 1st ResXMLTree_attribute
+            gap_size = attr_start - 20
+            file.read(gap_size)
         attributes_data = file.read(attr_size * attr_count)
         attributes = XmlAttributeElement.parse(io.BytesIO(attributes_data), attr_count, attr_size)
         return cls(header_t, attrext, attributes, (attrext_data + attributes_data))
@@ -596,23 +600,27 @@ class ManifestStruct:
     @staticmethod
     def check_reached_element(file: io.BytesIO):
         """
-        Static method to check if the next element right after the resource map chunk has been reached. There is only a
-        set of possible elements after the resource map chunk that could be met.
+        Static method to check if the next element right after the resource map chunk has been reached.
+        Android tolerates unknown chunk types, so we only need to verify
+        there's enough data for a header and that the header size is plausible.
+        Reference: AOSP ResXMLTree::setTo()
 
         :param file: The AndroidManifest file
         :type file: io.BytesIO
         """
-        possible_types = {256, 257, 258, 259, 260}
-        min_size = 8
+        min_size = 8  # 2 bytes type, 2 bytes header_size, 4 bytes total_size
         while True:
             cur_pos = file.tell()
-            if file.getbuffer().nbytes < cur_pos + min_size:  # we reached the end of the file
+            if file.getbuffer().nbytes < cur_pos + min_size:
+                break  # not enough data for a header
+            try:
+                _type, _header_size, _size = struct.unpack('<HHL', file.read(8))
+                file.seek(cur_pos)
+                if min_size <= _header_size <= _size:
+                    return True  # Valid header, regardless of type
+            except struct.error:
                 break
-            _type, _header_size, _size = struct.unpack('<HHL', file.read(8))
-            file.seek(cur_pos)
-            if _type in possible_types and _header_size >= min_size:
-                return True
-            file.read(1)
+            file.seek(cur_pos + 1)  # Try next byte if not valid
 
     @staticmethod
     def parse_next_header(file):
@@ -631,10 +639,8 @@ class ManifestStruct:
         if chunk_header is None:  # end of file
             return None
         chunk_type = hex(chunk_header.type)
-        if chunk_type in chunk_type_handlers:
-            return chunk_type_handlers[chunk_type](file, chunk_header_total)
-        else:
-            raise NotImplementedError(f"Unsupported chunk type: {chunk_type}")
+        handler = chunk_type_handlers.get(chunk_type, chunk_type_handlers['default'])
+        return handler(file, chunk_header_total)
 
     @staticmethod
     def process_elements(file, num_of_elements=None):
@@ -658,7 +664,11 @@ class ManifestStruct:
             resXMLTree_node = ResXMLHeader.parse(file)
             cur_elem_data = read_remaining(file, resXMLTree_node.header)
             elem_data = resXMLTree_node.header.data + resXMLTree_node.data + cur_elem_data
-            elements.append(ManifestStruct.parse_next_header(io.BytesIO(elem_data)))
+            element = ManifestStruct.parse_next_header(io.BytesIO(elem_data))
+            if isinstance(element, dict) and "raw" in element:
+                logging.warning(f"Unknown chunk type found: {element['type']}")
+                continue  # TODO: consider value in collecting this!
+            elements.append(element)
             if num_of_elements is None:
                 continue
             if len(elements) == num_of_elements:
@@ -713,15 +723,30 @@ class ManifestStruct:
         return cls(header, string_pool, resource_map, elements)
 
 
+def handle_unknown_chunk(file: io.BytesIO, header_t: ResXMLHeader):
+    """
+    Default handler for unknown chunk types.
+    # ResourceTypes.cpp skips unrecognized chunk types
+    # as long as their size and header are valid.
+    # Reference: AOSP ResXMLTree::setTo() and ResXMLParser::nextNode()
+    """
+    data = read_remaining(file, header_t.header)
+    # Optional: return raw chunk for logging or malware analysis
+    return {
+        "type": hex(header_t.header.type),
+        "raw": data
+    }
+
+
 chunk_type_handlers = {
     '0x100': XmlStartNamespace.parse,  # RES_XML_START_NAMESPACE_TYPE
     '0x101': XmlEndNamespace.parse,  # RES_XML_END_NAMESPACE_TYPE
     '0x102': XmlStartElement.parse,  # RES_XML_START_ELEMENT_TYPE
     '0x103': XmlEndElement.parse,  # RES_XML_END_ELEMENT_TYPE
     '0x104': XmlcDataElement.parse,  # RES_XML_CDATA_TYPE
+    'default': handle_unknown_chunk  # fallback
 }
 
-
 def read_remaining(file: io.BytesIO, header: ResChunkHeader):
     """
 
@@ -752,10 +777,16 @@ def process_attributes(attributes, string_list, ns_dict):
     """
     attribute_list = []
     for attr in attributes:
-        name = string_list[attr.name_index]
+        try:
+            name = string_list[attr.name_index]
+        except:
+            continue
         if not name:  # It happens that the attr.name_index points to an empty string in StringPool and you have to use
             # the public.xml. It falls outside the scope of the tool, so I am not going to solve it for now.
             name = f'Unknown_Attribute_Name_{random.randint(1000, 9999)}'
+        if "\n" in name:
+            # may be obfuscated attribute - https://github.com/REAndroid/APKEditor
+            continue
         if attr.typed_value_datatype == 1:  # reference type
             value = f"@{attr.typed_value_data}"
         elif attr.typed_value_datatype == 3:  # string type
@@ -803,10 +834,9 @@ def create_manifest(elements, string_list):
     ns_declared = []
     for element in elements:
         if isinstance(element, XmlStartNamespace):
-            namespaces[
-                string_list[
-                    element.ext[0]]] = f'xmlns:{string_list[element.ext[0]]}="{string_list[element.ext[1]]}"'
-            ns_dict[string_list[element.ext[1]]] = string_list[element.ext[0]]
+            if element.ext[0] < len(string_list) or element.ext[1] < len(string_list):
+                namespaces[string_list[element.ext[0]]] = f'xmlns:{string_list[element.ext[0]]}="{string_list[element.ext[1]]}"'
+                ns_dict[string_list[element.ext[1]]] = string_list[element.ext[0]]
         elif isinstance(element, XmlStartElement):
             attributes = process_attributes(element.attributes, string_list, ns_dict)
             attr_ns_list = set(ns.split(':')[0] for ns in attributes.split(' ') if ':' in ns)
